==> libreoffice-components-3.3.2.2.tar.bz2: libreoffice-components-3.3.2.2/automation/source/testtool/cretstrm.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 * 
 * Copyright 2000, 2010 Oracle and/or its affiliates.
 *
 * OpenOffice.org - a multi-platform office productivity suite
 *
 * This file is part of OpenOffice.org.
 *
 * OpenOffice.org is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * OpenOffice.org is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details
 * (a copy is included in the LICENSE file that accompanied this code).
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with OpenOffice.org.  If not, see
 * <http://www.openoffice.org/license.html>
 * for a copy of the LGPLv3 License.
 *
 ************************************************************************/

// MARKER(update_precomp.py): autogen include statement, do not remove
#include "precompiled_automation.hxx"
#include "cretstrm.hxx"
#include <tools/debug.hxx>
#include "rcontrol.hxx"
#include "svcommstream.hxx"


SV_IMPL_REF(SbxBase)

CRetStream::CRetStream(SvStream *pIn)
{
    pSammel = pIn;
    delete pCommStream;
    pCommStream = new SvCommStream( pSammel );
}

CRetStream::~CRetStream()
{
    delete pCommStream;
}

void CRetStream::Read ( String &aString )
{
    comm_UniChar* pStr;
    USHORT nLenInChars;
    CmdBaseStream::Read( pStr, nLenInChars );

    aString = String( pStr, nLenInChars );
    delete [] pStr;
}

void CRetStream::Read( SbxValue &aValue )
{
    *pSammel >> nId;
    if (nId != BinSbxValue)
    {
        DBG_ERROR1( "Falscher Typ im Stream: Erwartet SbxValue, gefunden :%hu", nId );
    }
    SbxBaseRef xBase = SbxBase::Load( *pSammel );
    if ( IS_TYPE( SbxValue, xBase ) )
        aValue = *PTR_CAST( SbxValue, &xBase );
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice-components-3.4.5.2.tar.bz2: libreoffice-components-3.4.5.2/automation/source/testtool/cretstrm.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 * 
 * Copyright 2000, 2010 Oracle and/or its affiliates.
 *
 * OpenOffice.org - a multi-platform office productivity suite
 *
 * This file is part of OpenOffice.org.
 *
 * OpenOffice.org is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * OpenOffice.org is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details
 * (a copy is included in the LICENSE file that accompanied this code).
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with OpenOffice.org.  If not, see
 * <http://www.openoffice.org/license.html>
 * for a copy of the LGPLv3 License.
 *
 ************************************************************************/

// MARKER(update_precomp.py): autogen include statement, do not remove
#include "precompiled_automation.hxx"
#include "cretstrm.hxx"
#include <tools/debug.hxx>
#include "rcontrol.hxx"
#include "svcommstream.hxx"


SV_IMPL_REF(SbxBase)

CRetStream::CRetStream(SvStream *pIn)
{
    pSammel = pIn;
    delete pCommStream;
    pCommStream = new SvCommStream( pSammel );
}

CRetStream::~CRetStream()
{
    delete pCommStream;
}

void CRetStream::Read ( String &aString )
{
    comm_UniChar* pStr;
    sal_uInt16 nLenInChars;
    CmdBaseStream::Read( pStr, nLenInChars );

    aString = String( pStr, nLenInChars );
    delete [] pStr;
}

void CRetStream::Read( SbxValue &aValue )
{
    *pSammel >> nId;
    if (nId != BinSbxValue)
    {
        OSL_TRACE( "Falscher Typ im Stream: Erwartet SbxValue, gefunden :%hu", nId );
    }
    SbxBaseRef xBase = SbxBase::Load( *pSammel );
    if ( IS_TYPE( SbxValue, xBase ) )
        aValue = *PTR_CAST( SbxValue, &xBase );
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
